const path = require('path');
const webpack = require('webpack');
const merge = require('webpack-merge');
const fs = require('fs');
const ExtractTextPlugin = require('extract-text-webpack-plugin');

const nodeModules = fs.readdirSync('node_modules').filter(function (x) { return x !== '.bin'; });

const PATHS = {
    source: path.join(__dirname, 'src'),
    output: path.join(__dirname, 'lib')
};

const commonConfig = merge([{
    entry: ['./src/mapper.js'],
    target: 'node',
    output: {
        path: PATHS.output,
        filename: 'mapper.js',
        libraryTarget: 'umd'
    },
    externals: nodeModules,
    module: {
        loaders: [
            {
                test: /\.js$/,
                loader: 'babel-loader',
                include: [PATHS.source],
                query: {
                    cacheDirectory: true
                }
            },
            {

                test: /\.scss$/,
                include: [PATHS.source],
                loaders: ['style-loader', 'css-loader', 'sass-loader']
            },
            {
                test: /\.css$/,
                loader: ExtractTextPlugin.extract('css-loader')
            },
            {
                test: /\.png$/,
                loader: 'url-loader?limit=100000'
            }
        ]
    },
    plugins: [
        new ExtractTextPlugin('mapper.css')
    ]
}]);

const productionConfig = merge([{
    plugins: [
        new webpack.DefinePlugin({
            'process.env': {
                'NODE_ENV': JSON.stringify('production')
            }
        }),
        new webpack.optimize.UglifyJsPlugin({
            compress: {
                warnings: true
            }
        })
    ]
}]);

const developmentConfig = merge([{

}]);

module.exports = (env) => {
    if (env === 'production') {
        return merge(commonConfig, productionConfig);
    }
    return merge(commonConfig, developmentConfig);
};